Installation
============

.. code-block:: bash

    $ pipenv install Stegano

You will be able to use Stéganô in your Python programs
or as a command line tool.

If you want to retrieve the source code (with the unit tests):

.. code-block:: bash

    $ git clone https://github.com/cedricbonhomme/Stegano.git

.. image:: https://api.travis-ci.org/cedricbonhomme/Stegano.svg?branch=master
    :target: https://travis-ci.org/cedricbonhomme/Stegano
